colour.models.cie_uvw Module — Colour 0.3.0 documentation

# colour.models.cie_uvw Module

## CIE UVW Colourspace

Defines the CIE UVW colourspace transformations:

- `XYZ_to_UVW()`

See also

CIE UVW Colourspace IPython Notebook

References

[1] | http://en.wikipedia.org/wiki/CIE_1964_color_space (Last accessed 10 June 2014)

`colour.models.cie_uvw.` `XYZ_to_UVW`(XYZ, illuminant=(0.34567, 0.3585))

  Converts from CIE XYZ colourspace to CIE 1964 U*VW** colourspace.

  Parameters: | XYZ (array_like, (3,)) – CIE XYZ colourspace matrix. illuminant (array_like, optional) – Reference illuminant chromaticity coordinates.
  Returns: | CIE 1964 U*VW** colourspace matrix.
  Return type: | ndarray, (3,)

  Notes

  - Input CIE XYZ colourspace matrix is in domain [0, 100].
  - Output CIE UVW colourspace matrix is in domain [0, 100].

  Warning

  The input / output domains of that definition are non standard!

  Examples

      >>> XYZ = np.array([11.80583421, 10.34, 5.15089229])
      >>> XYZ_to_UVW(XYZ)
      array([ 24.2543371...,   7.2205484...,  37.4645000...])